from distutils.core import setup
setup(
	name		= 'aaa103439',
	version 	= '1.2.0',
	py_modules	= ['aaa103439'],
	author		= 'spinestars',
	author_email	= 'spinestars@sina.com',
	url		= 'http://test.com',
	description	= 'print list',
)
